::: sleeplab_format.reader
    options:
        members:
            - read_dataset
            - read_series
            - read_subjects
            - read_annotations
            - read_sample_arrays
